summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorBert Belder <bertbelder@gmail.com>2012-06-20 00:56:33 +0200
committerBert Belder <bertbelder@gmail.com>2012-06-20 00:56:33 +0200
commit7a4dfb6aa8544805a638bf59d07648b1b6ce8142 (patch)
tree207100ad3b581f6bf1793d14462f3d6954106ffc /test
parent3795d771135309bff5f169111b6efdec1aef6c32 (diff)
downloadnodejs-7a4dfb6aa8544805a638bf59d07648b1b6ce8142.tar.gz
nodejs-7a4dfb6aa8544805a638bf59d07648b1b6ce8142.tar.bz2
nodejs-7a4dfb6aa8544805a638bf59d07648b1b6ce8142.zip
test-cluster-worker-kill: use SIGKILL instead of SIGHUP
In this test sending SIGKILL has the same effect as sending SIGHUP, but SIGKILL has the advantage that it works on Windows too.
Diffstat (limited to 'test')
-rw-r--r--test/simple/test-cluster-worker-kill.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/simple/test-cluster-worker-kill.js b/test/simple/test-cluster-worker-kill.js
index 9fd13ad65..284b83e7f 100644
--- a/test/simple/test-cluster-worker-kill.js
+++ b/test/simple/test-cluster-worker-kill.js
@@ -21,7 +21,7 @@
// test-cluster-worker-kill.js
// verifies that, when a child process is killed (we use SIGHUP)
// - the parent receives the proper events in the proper order, no duplicates
// - the exitCode and signalCode are correct in the 'exit' event
// - the worker.suicide flag, and worker.state are correct
@@ -40,7 +40,7 @@ if (cluster.isWorker) {
} else if (cluster.isMaster) {
- var KILL_SIGNAL = 'SIGHUP',
+ var KILL_SIGNAL = 'SIGKILL',
expected_results = {
cluster_emitDisconnect: [1, "the cluster did not emit 'disconnect'"],
cluster_emitExit: [1, "the cluster did not emit 'exit'"],
@@ -21,7 +21,7 @@
// test-cluster-worker-kill.js
-// verifies that, when a child process is killed (we use SIGHUP)
+// verifies that, when a child process is killed (we use SIGKILL)
// - the parent receives the proper events in the proper order, no duplicates
// - the exitCode and signalCode are correct in the 'exit' event